# gee.py
def download_satellite_data(aoi, start_date, end_date):
    """
    Download satellite data from GEE for a given area of interest (AOI).
    """
    return f"Downloading data for AOI: {aoi}, from {start_date} to {end_date}."

